VerifiableCircuit

Struct VerifiableCircuit 

pub struct VerifiableCircuit<F: Halo2FFTFriendlyField> {
    circuit_description: GKRCircuitDescription<F>,
    predetermined_public_inputs: HashMap<LayerId, MultilinearExtension<F>>,
    committed_inputs: HashMap<LayerId, LigeroInputLayerDescriptionWithOptionalVerifierPrecommit<F>>,
    layer_label_to_layer_id: HashMap<String, LayerId>,
}
A circuit that contains a GKRCircuitDescription alongside a description of the committed input layers.

Fields

circuit_description: GKRCircuitDescription<F>predetermined_public_inputs: HashMap<LayerId, MultilinearExtension<F>>

A partial mapping of public input layers to MLEs. Some (or all) public input layer IDs may be missing. The input layers present in this mapping are public input data that the verifier placed in the circuit, and which will be checked for equality with the respective public inputs in the proof during verification.

committed_inputs: HashMap<LayerId, LigeroInputLayerDescriptionWithOptionalVerifierPrecommit<F>>layer_label_to_layer_id: HashMap<String, LayerId>

Implementations

Source

impl<F: Halo2FFTFriendlyField> VerifiableCircuit<F>

pub fn new( circuit_description: GKRCircuitDescription<F>, predetermined_public_inputs: HashMap<LayerId, MultilinearExtension<F>>, committed_inputs: HashMap<LayerId, LigeroInputLayerDescriptionWithOptionalVerifierPrecommit<F>>, layer_label_to_layer_id: HashMap<String, LayerId>, ) -> Self

Returns a VerifiableCircuit initialized with the given data.

pub fn get_committed_inputs_ref( &self, ) -> &HashMap<LayerId, LigeroInputLayerDescriptionWithOptionalVerifierPrecommit<F>>

Returns a reference to the mapping which maps a LayerId of a committed input layer to its description.

TODO: This is too transparent. Replace this with methods that answer the queries of the prover directly, and do not expose it to the circuit developer.

pub fn get_gkr_circuit_description_ref(&self) -> &GKRCircuitDescription<F>

Returns a reference to the circuit description.

TODO: This is only used by the back end. Do not expose it to the circuit developer.

pub fn get_public_input_layer_ids(&self) -> Vec<LayerId>

Returns a vector of the LayerIds of all input layers which are public.

pub fn get_committed_input_layer_ids(&self) -> Vec<LayerId>

Returns a vector of the LayerIds of all input layers which are committed to using a PCS.

pub fn get_predetermined_public_input_mle_ref( &self, layer_id: &LayerId, ) -> Option<&MultilinearExtension<F>>

Returns the data associated with the public input layer with ID layer_id, or None if no such public input layer exists.

pub fn set_pre_commitment( &mut self, layer_label: &str, commitment: LigeroRoot<F>, ) -> Result<()>

Sets the pre-commitment of the input layer with label layer_label to commitment. Pre-commitments allow the verifier to check that an input layer commitment in the proof is the same as the expected commitment provided here.

Panics

If layer_label is not a valid committed input layer label.

pub fn verify( &self, circuit_description_hash_type: CircuitHashType, transcript: &mut impl VerifierTranscript<F>, proof_config: &ProofConfig, ) -> Result<()>

Verify a GKR proof from a transcript.